@@ -54,7 +54,8 @@ class GenericCRUD(metaclass=MetaLogger, object=LOGGER_CRUD_CODE_OBJECT):
         """Inserts a new row into the table and returns the id of the new row or -1 if an error occurred."""
 
         if ignore_duplicate:
-            self.logger.warning("GenericCRUD.insert using ignore_duplicate, is it really needed?")
+          #TODO Also display the data_json
+          self.logger.warning("GenericCRUD.insert("+str(schema_name)+"."+str(table_name)+") using ignore_duplicate, is it needed?")
 
         table_name = table_name or self.default_table_name
         schema_name = schema_name or self.schema_name
